====================
RuleMajorityJudgment
====================

.. autoclass:: svvamp.RuleMajorityJudgment
   :members: ballots_, scores_, w_,
             min_grade, max_grade, step_grade, rescale_grades
